Index: src/ast.cc |
diff --git a/src/ast.cc b/src/ast.cc |
index bf16b9c076b8786ce1cb4a2eecf4963f79d70fe9..53d27999ea073768fd0f879121cddf7964974732 100644 |
--- a/src/ast.cc |
+++ b/src/ast.cc |
@@ -1117,9 +1117,11 @@ void AstConstructionVisitor::VisitCallRuntime(CallRuntime* node) { |
// optimize them. |
add_flag(kDontInline); |
} else if (node->function()->intrinsic_type == Runtime::INLINE && |
- node->raw_name()->IsOneByteEqualTo("_Arguments")) { |
- // Don't inline the %_Arguments because it's implementation will not work. |
- // There is no stack frame to get them from. |
+ (node->raw_name()->IsOneByteEqualTo("_ArgumentsLength") || |
+ node->raw_name()->IsOneByteEqualTo("_Arguments"))) { |
+ // Don't inline the %_ArgumentsLength or %_Arguments because their |
+ // implementation will not work. There is no stack frame to get them |
+ // from. |
add_flag(kDontInline); |
} |
} |